Local structure order parameters
================================

.. featurizer::  LSOP
    :id: LSOP
    :considers_geometry: True
    :considers_structure_graph: False
    :encodes_chemistry: False
    :scope: bu
    :scalar: False
